@@ -17,6 +17,14 @@
   (at your option) any later version.
 */
 
+#include <qglobal.h>
+
+#ifdef Q_OS_WIN
+// Prevent windows system header files from defining min/max as macros.
+#define NOMINMAX 1
+#include <winsock2.h>
+#endif
+
 #include "transfersend.h"
 #include "dcccommon.h"
 #include "transfermanager.h"
@@ -157,7 +165,7 @@ namespace Konversation
                 m_ownIp = DccCommon::getOwnIp(Application::instance()->getConnectionManager()->getServerByConnectionId(m_connectionId));
             }
 
-            if (!KAuthorized::authorizeKAction("allow_downloading"))
+            if (!KAuthorized::authorizeAction("allow_downloading"))
             {
                 //Do not have the rights to send the file.  Shouldn't have gotten this far anyway
                 //Note this is after the initialisation so the view looks correct still
@@ -391,7 +399,7 @@ namespace Konversation
 
                 if (error)
                 {
-                    server->appendMessageToFrontmost(i18nc("Universal Plug and Play", "UPnP"), i18n("Failed to forward port %1. Sending DCC request to remote user regardless.", QString::number(m_ownPort)), false);
+                    server->appendMessageToFrontmost(i18nc("Universal Plug and Play", "UPnP"), i18n("Failed to forward port %1. Sending DCC request to remote user regardless.", QString::number(m_ownPort)), QHash<QString, QString>(), false);
                 }
             }
 
@@ -547,7 +555,7 @@ namespace Konversation
             while (m_sendSocket->bytesAvailable() >= 4)
             {
                 m_sendSocket->read((char*)&pos, 4);
-                pos = intel(pos);
+                pos = ntohl(pos);
 
                 //qDebug() << pos  << "/" << m_fileSize;
                 if (pos == m_fileSize)
