@@ -13,12 +13,12 @@
 
 #include "modebutton.h"
 
-
 ModeButton::ModeButton(const QString& label,QWidget* parent,int newId) :
-QPushButton(label,parent)
+QToolButton(parent)
 {
     id=newId;
     on=false;
+    setText(label);
     setCheckable(true);
     connect(this, &ModeButton::clicked, this, &ModeButton::wasClicked);
 }
@@ -30,12 +30,12 @@ ModeButton::~ModeButton()
 void ModeButton::setOn(bool state)
 {
     on=state;
-    QPushButton::setChecked(state);
+    QToolButton::setChecked(state);
 }
 
 void ModeButton::wasClicked()
 {
-    emit clicked(id,!on);
+    emit modeClicked(id, !on);
     // Keep button in old state, since we don't know if mode change will
     // eventually work. If we aren't channel operator, it won't.
     setOn(on);
