@@ -21,7 +21,7 @@
 #include <QTreeWidget>
 
 
-class KUrl;
+class QUrl;
 
 class HighlightViewItem : public QTreeWidgetItem
 {
@@ -41,8 +41,8 @@ class HighlightViewItem : public QTreeWidgetItem
         void setColor(const QColor color);
         QColor getColor() const;
 
-        void setSoundURL(const KUrl& url);
-        KUrl getSoundURL() const;
+        void setSoundURL(const QUrl &url);
+        QUrl getSoundURL() const;
 
         void setAutoText(const QString& autoText);
         QString getAutoText() const;
@@ -58,7 +58,7 @@ class HighlightViewItem : public QTreeWidgetItem
 
         QString m_pattern;
         QColor m_color;
-        KUrl m_soundURL;
+        QUrl m_soundURL;
         QString m_autoText;
         QString m_chatWindows;
         bool m_notify;
