@@ -254,6 +254,23 @@ void ViewContainer::setupTabWidget()
     updateTabWidgetAppearance();
 }
 
+void ViewContainer::resetFont()
+{
+    m_frontView->getTextView()->resetFontSize();
+}
+
+void ViewContainer::zoomIn()
+{
+    if (m_frontView->getTextView())
+        m_frontView->getTextView()->increaseFontSize();
+}
+
+void ViewContainer::zoomOut()
+{
+    if (m_frontView->getTextView())
+        m_frontView->getTextView()->decreaseFontSize();
+}
+
 void ViewContainer::setupViewTree()
 {
     unclutterTabs();
@@ -629,7 +646,7 @@ bool ViewContainer::dropMimeData(const QMimeData *data, Qt::DropAction action, i
             return false;
         }
 
-        for (int i = row < dragIdx.row() ? 0 : 1; i < std::abs(dragIdx.row() - row); ++i) {
+        for (int i = row < dragIdx.row() ? 0 : 1; i < qAbs(dragIdx.row() - row); ++i) {
             (row < dragIdx.row()) ? moveViewLeft() : moveViewRight();
         }
 
@@ -717,9 +734,9 @@ void ViewContainer::updateTabWidgetAppearance()
     m_tabWidget->setDocumentMode(true);
 
     if (Preferences::self()->customTabFont())
-        m_tabWidget->setFont(Preferences::self()->tabFont());
+        m_tabWidget->tabBar()->setFont(Preferences::self()->tabFont());
     else
-        m_tabWidget->setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
+        m_tabWidget->tabBar()->setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
 
     m_tabWidget->setTabPosition((Preferences::self()->tabPlacement()==Preferences::Top) ?
         QTabWidget::North : QTabWidget::South);
@@ -761,11 +778,9 @@ void ViewContainer::updateViewActions(int index)
             action = actionCollection()->action("reconnect_server");
             if (action) action->setEnabled(true);
 
-
             action = actionCollection()->action("disconnect_server");
             if (action) action->setEnabled(server->isConnected() || server->isConnecting() || server->isScheduledToConnect());
 
-
             action = actionCollection()->action("join_channel");
             if (action) action->setEnabled(server->isConnected());
         }
@@ -826,6 +841,15 @@ void ViewContainer::updateViewActions(int index)
         action = actionCollection()->action("clear_tabs");
         if (action) action->setEnabled(true);
 
+        action = actionCollection()->action("increase_font");
+        if (action) action->setEnabled(true);
+
+        action = actionCollection()->action("shrink_font");
+        if (action) action->setEnabled(true);
+
+        action = actionCollection()->action("reset_font");
+        if (action) action->setEnabled(true);
+
         action = actionCollection()->action("toggle_away");
         if (action) action->setEnabled(true);
 
@@ -2016,6 +2040,9 @@ void ViewContainer::cleanupAfterClose(ChatWindow* view)
         const int tabIndex = m_tabWidget->indexOf(view);
 
         if (tabIndex != -1) {
+            if (tabIndex == m_popupViewIndex)
+                m_popupViewIndex = -1;
+
             m_tabWidget->blockSignals(true);
 
             const QModelIndex& idx = indexForView(view);
@@ -2378,7 +2405,7 @@ void ViewContainer::findPrevText()
     }
 }
 
-void ViewContainer::appendToFrontmost(const QString& type,const QString& message,ChatWindow* serverView, bool parseURL)
+void ViewContainer::appendToFrontmost(const QString& type, const QString& message, ChatWindow* serverView, const QHash<QString, QString> &messageTags, bool parseURL)
 {
     if (!m_tabWidget) return;
 
@@ -2404,14 +2431,14 @@ void ViewContainer::appendToFrontmost(const QString& type,const QString& message
         Preferences::self()->redirectServerAndAppMsgToStatusPane())
     {
         // if not, take server specified fallback view instead
-        serverView->appendServerMessage(type,  message, parseURL);
+        serverView->appendServerMessage(type,  message, messageTags, parseURL);
         // FIXME: this signal should be sent from the status panel instead, so it
         //        can be using the correct highlight color, would be more consistent
         //        anyway!
         // FIXME newText(serverView,QString::null,true);
     }
     else
-        m_frontView->appendServerMessage(type, message, parseURL);
+        m_frontView->appendServerMessage(type, message, messageTags, parseURL);
 }
 
 void ViewContainer::insertCharacter()
@@ -2427,18 +2454,18 @@ void ViewContainer::insertCharacter()
     if (!m_insertCharDialog)
     {
         m_insertCharDialog = new Konversation::InsertCharDialog(font.family(), m_window);
-        connect(m_insertCharDialog, SIGNAL(insertChar(QChar)), this, SLOT(insertChar(QChar)));
+        connect(m_insertCharDialog, SIGNAL(insertChar(uint)), this, SLOT(insertChar(uint)));
     }
 
     m_insertCharDialog->setFont(font);
     m_insertCharDialog->show();
 }
 
-void ViewContainer::insertChar(const QChar& chr)
+void ViewContainer::insertChar(uint chr)
 {
     ChatWindow* view = static_cast<ChatWindow*>(m_tabWidget->currentWidget());
 
-    if (view) view->appendInputText(chr, true/*fromCursor*/);
+    if (view) view->appendInputText(QString::fromUcs4(&chr, 1), true/*fromCursor*/);
 }
 
 void ViewContainer::insertIRCColor()
@@ -2629,7 +2656,14 @@ void ViewContainer::closeDccPanel()
     if (m_dccPanel && m_dccPanelOpen)
     {
         // hide it from view, does not delete it
-        if (m_tabWidget) m_tabWidget->removeTab(m_tabWidget->indexOf(m_dccPanel));
+        if (m_tabWidget)
+        {
+            if (m_popupViewIndex == m_tabWidget->indexOf(m_dccPanel)) {
+                m_popupViewIndex = -1;
+            }
+
+            cleanupAfterClose(m_dccPanel);
+        }
         m_dccPanelOpen=false;
         (dynamic_cast<KToggleAction*>(actionCollection()->action("open_dccstatus_window")))->setChecked(false);
     }
@@ -2752,9 +2786,8 @@ void ViewContainer::showJoinChannelDialog()
     if (dlg->exec() == QDialog::Accepted)
     {
         Server *server = Application::instance()->getConnectionManager()->getServerByConnectionId(dlg->connectionId());
-        if (!server)
-          return;
-        server->sendJoinCommand(dlg->channel(), dlg->password());
+        if (server)
+            server->sendJoinCommand(dlg->channel(), dlg->password());
     }
     delete dlg;
 }
@@ -2915,8 +2948,6 @@ void ViewContainer::closeQueries()
         ++operations;
     }
 
-    m_queryViewCount = 0;
-
     actionCollection()->action("close_queries")->setEnabled(false);
 }
 
